==> google-cloud-storage-1.13.0.tar.gz: google-cloud-storage-1.13.0/google/cloud/storage/__init__.py <==
# Copyright 2014 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Shortcut methods for getting set up with Google Cloud Storage.

You'll typically use these to get started with the API:

.. literalinclude:: snippets.py
    :start-after: [START storage_get_started]
    :end-before: [END storage_get_started]

The main concepts with this API are:

- :class:`~google.cloud.storage.bucket.Bucket` which represents a particular
  bucket (akin to a mounted disk on a computer).

- :class:`~google.cloud.storage.blob.Blob` which represents a pointer to a
  particular entity in Cloud Storage (akin to a file path on a remote
  machine).
"""


from pkg_resources import get_distribution
__version__ = get_distribution('google-cloud-storage').version

from google.cloud.storage.batch import Batch
from google.cloud.storage.blob import Blob
from google.cloud.storage.bucket import Bucket
from google.cloud.storage.client import Client


__all__ = ['__version__', 'Batch', 'Blob', 'Bucket', 'Client']

==> google-cloud-storage-1.28.0.tar.gz: google-cloud-storage-1.28.0/google/cloud/storage/__init__.py <==
# Copyright 2014 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Shortcut methods for getting set up with Google Cloud Storage.

You'll typically use these to get started with the API:

.. literalinclude:: snippets.py
    :start-after: [START storage_get_started]
    :end-before: [END storage_get_started]

The main concepts with this API are:

- :class:`~google.cloud.storage.bucket.Bucket` which represents a particular
  bucket (akin to a mounted disk on a computer).

- :class:`~google.cloud.storage.blob.Blob` which represents a pointer to a
  particular entity in Cloud Storage (akin to a file path on a remote
  machine).
"""


from pkg_resources import get_distribution

__version__ = get_distribution("google-cloud-storage").version

from google.cloud.storage.batch import Batch
from google.cloud.storage.blob import Blob
from google.cloud.storage.bucket import Bucket
from google.cloud.storage.client import Client


__all__ = ["__version__", "Batch", "Blob", "Bucket", "Client"]
